import { Observable } from 'rxjs';
import { NgZone } from '@angular/core';
import { EventEmitter } from '@angular/core';
import { Router } from '@angular/router';
import { AuthorizationResult } from '../models/authorization-result.enum';
import { AuthConfiguration, OpenIDImplicitFlowConfiguration } from '../modules/auth.configuration';
import { StateValidationService } from './oidc-security-state-validation.service';
import { OidcSecurityCheckSession } from './oidc.security.check-session';
import { OidcSecurityCommon } from './oidc.security.common';
import { OidcSecuritySilentRenew } from './oidc.security.silent-renew';
import { OidcSecurityUserService } from './oidc.security.user-service';
import { OidcSecurityValidation } from './oidc.security.validation';
import { OidcDataService } from './oidc-data.service';
import { TokenHelperService } from './oidc-token-helper.service';
import { LoggerService } from './oidc.logger.service';
import { AuthWellKnownEndpoints } from '../models/auth.well-known-endpoints';
export declare class OidcSecurityService {
    private platformId;
    private oidcDataService;
    private stateValidationService;
    private authConfiguration;
    private router;
    private oidcSecurityCheckSession;
    private oidcSecuritySilentRenew;
    private oidcSecurityUserService;
    private oidcSecurityCommon;
    private oidcSecurityValidation;
    private tokenHelperService;
    private loggerService;
    private zone;
    onModuleSetup: EventEmitter<boolean>;
    onAuthorizationResult: EventEmitter<AuthorizationResult>;
    onCheckSessionChanged: EventEmitter<boolean>;
    checkSessionChanged: boolean;
    moduleSetup: boolean;
    private authWellKnownEndpoints;
    private _isAuthorized;
    private _isAuthorizedValue;
    private lastUserData;
    private _userData;
    private authWellKnownEndpointsLoaded;
    private runTokenValidationRunning;
    private _scheduledHeartBeat;
    private boundSilentRenewEvent;
    constructor(platformId: Object, oidcDataService: OidcDataService, stateValidationService: StateValidationService, authConfiguration: AuthConfiguration, router: Router, oidcSecurityCheckSession: OidcSecurityCheckSession, oidcSecuritySilentRenew: OidcSecuritySilentRenew, oidcSecurityUserService: OidcSecurityUserService, oidcSecurityCommon: OidcSecurityCommon, oidcSecurityValidation: OidcSecurityValidation, tokenHelperService: TokenHelperService, loggerService: LoggerService, zone: NgZone);
    setupModule(openIDImplicitFlowConfiguration: OpenIDImplicitFlowConfiguration, authWellKnownEndpoints: AuthWellKnownEndpoints): void;
    getUserData(): Observable<any>;
    getIsAuthorized(): Observable<boolean>;
    getToken(): string;
    getIdToken(): string;
    getPayloadFromIdToken(encode?: boolean): any;
    setState(state: string): void;
    getState(): string;
    setCustomRequestParameters(params: {
        [key: string]: string | number | boolean;
    }): void;
    authorize(urlHandler?: (url: string) => any): void;
    authorizedCallback(hash?: string): void;
    getUserinfo(isRenewProcess?: boolean, result?: any, id_token?: any, decoded_id_token?: any): Observable<boolean>;
    logoff(): void;
    refreshSession(): Observable<any>;
    handleError(error: any): void;
    startCheckingSilentRenew(): void;
    stopCheckingSilentRenew(): void;
    private getValidatedStateResult(result, jwtKeys);
    private setUserData(userData);
    private setIsAuthorized(isAuthorized);
    private setAuthorizationData(access_token, id_token);
    private createAuthorizeUrl(redirect_url, nonce, state, authorization_endpoint, prompt?);
    private createEndSessionUrl(end_session_endpoint, id_token_hint);
    private resetAuthorizationData(isRenewProcess);
    private onUserDataChanged();
    private getSigningKeys();
    private handleErrorGetSigningKeys(error);
    private runTokenValidation();
    private silentRenewEventHandler(e);
}
